module.exports = defineTest({
	description: 'avoids infinite recursions when deoptimizing "this" context'
});
